@@ -5,8 +5,8 @@
 
 #include <cstdlib>
 
-#include <arc/client/Broker.h>
-#include <arc/client/ExecutionTarget.h>
+#include <arc/compute/Broker.h>
+#include <arc/compute/ExecutionTarget.h>
 
 namespace Arc {
 
@@ -18,6 +18,8 @@ namespace Arc {
       BrokerPluginArgument *brokerarg = dynamic_cast<BrokerPluginArgument*>(arg);
       return brokerarg ? new RandomBrokerPlugin(brokerarg) : NULL;
     }
+
+    virtual bool match(const ExecutionTarget& et) const { return BrokerPlugin::match(et); }
     
     virtual bool operator()(const ExecutionTarget&, const ExecutionTarget&) const { return (bool)(std::rand()%2); }
   };
