@@ -139,12 +139,23 @@ bool HTTPSecAttr::Export(SecAttrFormat format,XMLNode &val) const {
 }
 
 MCC_HTTP_Service::MCC_HTTP_Service(Config *cfg,PluginArgument* parg):MCC_HTTP(cfg,parg) {
+  XMLNode header_node = (*cfg)["Header"];
+  while(header_node) {
+    std::string header = (std::string)header_node;
+    std::string::size_type pos = header.find(':');
+    if (pos == std::string::npos) {
+      headers_.push_back(std::make_pair(Arc::trim(header), std::string()));
+    } else {
+      headers_.push_back(std::make_pair(Arc::trim(header.substr(0,pos)), Arc::trim(header.substr(pos+1))));
+    }
+    ++header_node;
+  }
 }
 
 MCC_HTTP_Service::~MCC_HTTP_Service(void) {
 }
 
-static MCC_Status make_http_fault(Logger& logger, PayloadHTTPIn &inpayload, PayloadStreamInterface& stream, Message& outmsg, int code, const char* desc = NULL) {
+static MCC_Status make_http_fault(Logger& logger, PayloadHTTPIn &inpayload, PayloadStreamInterface& stream, Message& outmsg, int code, std::list< std::pair<std::string,std::string> > & headers, const char* desc = NULL) {
   if((desc == NULL) || (*desc == 0)) {
     switch(code) {
       case HTTP_BAD_REQUEST:  desc="Bad Request"; break;
@@ -158,6 +169,10 @@ static MCC_Status make_http_fault(Logger& logger, PayloadHTTPIn &inpayload, Payl
   PayloadHTTPOut outpayload(code,desc);
   bool keep_alive = (!inpayload)?false:inpayload.KeepAlive();
   outpayload.KeepAlive(keep_alive);
+  // Add forced headers
+  for(std::list< std::pair<std::string,std::string> >::iterator header = headers.begin(); header != headers.end(); ++header) {
+    outpayload.Attribute(header->first, header->second);
+  }
   if(!outpayload.Flush(stream)) return MCC_Status();
   // Returning empty payload because response is already sent
   outmsg.Payload(new PayloadRaw);
@@ -168,8 +183,8 @@ static MCC_Status make_http_fault(Logger& logger, PayloadHTTPIn &inpayload, Payl
   return MCC_Status(STATUS_OK);
 }
 
-static MCC_Status make_http_fault(Logger& logger, PayloadHTTPIn &inpayload, PayloadStreamInterface& stream, Message& outmsg, int code, std::string const & desc) {
-  return make_http_fault(logger, inpayload, stream, outmsg, code, desc.empty()?"":desc.c_str());
+static MCC_Status make_http_fault(Logger& logger, PayloadHTTPIn &inpayload, PayloadStreamInterface& stream, Message& outmsg, int code, std::list< std::pair<std::string,std::string> > const & headers, std::string const & desc) {
+  return make_http_fault(logger, inpayload, stream, outmsg, code, headers, desc.empty()?"":desc.c_str());
 }
 
 static MCC_Status make_raw_fault(Message& outmsg,const char* desc = NULL) {
@@ -224,7 +239,7 @@ MCC_Status MCC_HTTP_Service::process(Message& inmsg,Message& outmsg) {
   PayloadHTTPIn nextpayload(*inpayload);
   if(!nextpayload) {
     logger.msg(WARNING, "Cannot create http payload");
-    return make_http_fault(logger,nextpayload,*inpayload,outmsg,HTTP_BAD_REQUEST);
+    return make_http_fault(logger,nextpayload,*inpayload,outmsg,HTTP_BAD_REQUEST,headers_);
   };
   if(nextpayload.Method() == "END") {
     return MCC_Status(SESSION_CLOSE);
@@ -286,7 +301,7 @@ MCC_Status MCC_HTTP_Service::process(Message& inmsg,Message& outmsg) {
   {
     MCC_Status sret = ProcessSecHandlers(nextinmsg,"incoming");
     if(!sret) {
-      return make_http_fault(logger,nextpayload,*inpayload,outmsg,HTTP_BAD_REQUEST,(std::string)sret); // Maybe not 400 ?
+      return make_http_fault(logger,nextpayload,*inpayload,outmsg,HTTP_BAD_REQUEST,headers_,(std::string)sret); // Maybe not 400 ?
     };
   };
   // Call next MCC
@@ -295,7 +310,7 @@ MCC_Status MCC_HTTP_Service::process(Message& inmsg,Message& outmsg) {
   if(!next) {
     logger.msg(WARNING, "No next element in the chain");
     // Here selection is on method name. So failure result is "not supported"
-    return make_http_fault(logger,nextpayload,*inpayload,outmsg,HTTP_NOT_IMPLEMENTED);
+    return make_http_fault(logger,nextpayload,*inpayload,outmsg,HTTP_NOT_IMPLEMENTED,headers_);
   }
   Message nextoutmsg = outmsg; nextoutmsg.Payload(NULL);
   MCC_Status ret = next->process(nextinmsg,nextoutmsg);
@@ -308,11 +323,11 @@ MCC_Status MCC_HTTP_Service::process(Message& inmsg,Message& outmsg) {
     std::string http_code_s = nextoutmsg.Attributes()->get("HTTP:CODE");
     std::string http_resp = nextoutmsg.Attributes()->get("HTTP:REASON");
     if (!http_code_s.empty()) stringto(http_code_s, http_code);
-    return make_http_fault(logger,nextpayload,*inpayload,outmsg,http_code,http_resp.c_str());
+    return make_http_fault(logger,nextpayload,*inpayload,outmsg,http_code,headers_,http_resp.c_str());
   }
   if(!nextoutmsg.Payload()) {
     logger.msg(WARNING, "next element of the chain returned no payload");
-    return make_http_fault(logger,nextpayload,*inpayload,outmsg,HTTP_INTERNAL_ERR);
+    return make_http_fault(logger,nextpayload,*inpayload,outmsg,HTTP_INTERNAL_ERR,headers_);
   }
   PayloadRawInterface* retpayload = NULL;
   PayloadStreamInterface* strpayload = NULL;
@@ -325,13 +340,13 @@ MCC_Status MCC_HTTP_Service::process(Message& inmsg,Message& outmsg) {
   if((!retpayload) && (!strpayload)) {
     logger.msg(WARNING, "next element of the chain returned invalid/unsupported payload");
     delete nextoutmsg.Payload();
-    return make_http_fault(logger,nextpayload,*inpayload,outmsg,HTTP_INTERNAL_ERR);
+    return make_http_fault(logger,nextpayload,*inpayload,outmsg,HTTP_INTERNAL_ERR,headers_);
   };
   {
     MCC_Status sret = ProcessSecHandlers(nextinmsg,"outgoing");
     if(!sret) {
       delete nextoutmsg.Payload();
-      return make_http_fault(logger,nextpayload,*inpayload,outmsg,HTTP_BAD_REQUEST,(std::string)sret); // Maybe not 400 ?
+      return make_http_fault(logger,nextpayload,*inpayload,outmsg,HTTP_BAD_REQUEST,headers_,(std::string)sret); // Maybe not 400 ?
     };
   };
   // Create HTTP response from raw body content
@@ -376,6 +391,10 @@ MCC_Status MCC_HTTP_Service::process(Message& inmsg,Message& outmsg) {
     soutpayload = new PayloadHTTPOutStream(http_code,http_resp,request_is_head);
     outpayload = soutpayload;
   };
+  // Add forced headers
+  for(std::list< std::pair<std::string,std::string> >::iterator header = headers_.begin(); header != headers_.end(); ++header) {
+    outpayload->Attribute(header->first, header->second);
+  }
   // Use attributes which higher level MCC may have produced for HTTP
   for(AttributeIterator i = nextoutmsg.Attributes()->getAll();i.hasMore();++i) {
     const char* key = i.key().c_str();
