@@ -12,10 +12,10 @@
 
 #include <arc/FileUtils.h>
 
-#define DELEGATION_USES_SQLITE 1
-
 #include "FileRecordSQLite.h"
+#ifdef HAVE_DBCXX
 #include "FileRecordBDB.h"
+#endif
 
 #include "DelegationStore.h"
 
@@ -29,9 +29,11 @@ namespace ARex {
     mtimeout_ = 0;
     mrec_ = NULL;
     switch(db) {
+#ifdef HAVE_DBCXX
       case DbBerkeley:
         fstore_ = new FileRecordBDB(base, allow_recover);
         break;
+#endif
       case DbSQLite:
         fstore_ = new FileRecordSQLite(base, allow_recover);
         break;
@@ -66,9 +68,11 @@ namespace ARex {
             };
           };
           switch(db) {
+#ifdef HAVE_DBCXX
             case DbBerkeley:
               fstore_ = new FileRecordBDB(base);
               break;
+#endif
             case DbSQLite:
               fstore_ = new FileRecordSQLite(base);
               break;
