@@ -135,7 +135,7 @@ then
   exit 1
 fi
 # See if executable is a script, and extract the name of the interpreter
-line1=`dd if="$executable" count=1 2>/dev/null | head -n 1`
+line1=$(dd if="$executable" count=1 2>/dev/null | head -n 1| tr -d '\0')
 command=`echo $line1 | sed -n 's/^#! *//p'`
 interpreter=`echo $command | awk '{print $1}'`
 if [ "$interpreter" = /usr/bin/env ]; then
