@@ -186,7 +186,7 @@ namespace ARex {
   //      expired]
   //   Timestamp (dateTime)
   //   Description 0-1
-  Arc::XMLNode addActivityStatusES(Arc::XMLNode pnode,const std::string& gm_state,bool failed,bool pending,const std::string& failedstate,const std::string& failedcause) {
+  Arc::XMLNode addActivityStatusES(Arc::XMLNode pnode,const std::string& gm_state,Arc::XMLNode glue_xml,bool failed,bool pending,const std::string& failedstate,const std::string& failedcause) {
     std::string primary_state;
     std::list<std::string> state_attributes;
     std::string glue_state("");
@@ -318,6 +318,10 @@ namespace ARex {
   }
 
 
+  std::string JobIDGeneratorREST::GetInterface(void) {
+    return "org.nordugrid.arcrest";
+  }
+
 
   JobIDGeneratorINTERNAL::JobIDGeneratorINTERNAL(const std::string& endpoint):endpoint_(endpoint) {
   }
