@@ -503,76 +503,5 @@ Arc::MCC_Status Service_PythonWrapper::process(Arc::Message& inmsg, Arc::Message
     return status;
 }
 
-bool Service_PythonWrapper::RegistrationCollector(Arc::XMLNode& doc) {
-    PyObject *arg = NULL;
-
-    // logger.msg(Arc::VERBOSE, "Python 'RegistrationCollector' wrapper process called");
-
-    if(!initialized) return false;
-
-    PythonLock plock(logger);
-
-    // Convert doc to XMLNodeP
-    // logger.msg(Arc::VERBOSE, "Convert doc to XMLNodeP");
-    Arc::XMLNodeP doc_ptr(doc);
-    if (!doc_ptr) {
-        logger.msg(Arc::ERROR, "Failed to create XMLNode container");
-        return false;
-    }
-
-    // Convert doc to Python object
-    // logger.msg(Arc::VERBOSE, "Convert doc to Python object");
-    // logger.msg(Arc::VERBOSE, "Create Python XMLNode");
-    // arc_dict is a borrowed reference
-    PyObject *arc_dict = PyModule_GetDict(arc_module);
-    if (arc_dict == NULL) {
-        logger.msg(Arc::ERROR, "Cannot get dictionary of ARC module");
-        if (PyErr_Occurred()) PyErr_Print();
-        return false;
-    }
-    // arc_xmlnode_klass is a borrowed reference
-    PyObject *arc_xmlnode_klass = PyDict_GetItemString(arc_dict, "XMLNode");
-    if (arc_xmlnode_klass == NULL) {
-        logger.msg(Arc::ERROR, "Cannot find ARC XMLNode class");
-        if (PyErr_Occurred()) PyErr_Print();
-        return false;
-    }
-    arg = Py_BuildValue("(l)", (long int)doc_ptr);
-    if (arg == NULL) {
-        logger.msg(Arc::ERROR, "Cannot create doc argument");
-        if (PyErr_Occurred()) PyErr_Print();
-        return false;
-    }
-    PyObjectP py_doc(PyObject_CallObject(arc_xmlnode_klass, arg));
-        if (!py_doc) {
-        logger.msg(Arc::ERROR, "Cannot convert doc to Python object");
-        if (PyErr_Occurred()) PyErr_Print();
-        Py_DECREF(arg);
-        return false;
-    }
-    Py_DECREF(arg);
-
-    // Call the RegistrationCollector method
-    // logger.msg(Arc::VERBOSE, "Call the RegistrationCollector method");
-    PyObjectP py_bool(PyObject_CallMethod(object, (char*)"RegistrationCollector", (char*)"(O)",
-                      (PyObject*)py_doc));
-
-    if (!py_bool) {
-        if (PyErr_Occurred()) PyErr_Print();
-        return false;
-    }
-
-    // Convert the return value of the function back to cpp
-    // logger.msg(Arc::VERBOSE, "Convert the return value of the function back to cpp");
-    bool *ret_val2 = (bool *)extract_swig_wrappered_pointer(py_bool);
-    bool return_value = false;
-    if (ret_val2) return_value = (*ret_val2);
-
-    XMLNode *doc2 = (XMLNode *)extract_swig_wrappered_pointer(py_doc);
-    if (doc2 == NULL) return false;
-    (*doc2).New(doc);
-    return return_value;
-}
-
 } // namespace Arc
 
